Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/memory/hipMemcpyAtoD.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

77 lines
2.1 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
#include <hip_test_common.hh>
#include <hip_test_checkers.hh>
/**
* @addtogroup hipMemcpyAtoD hipMemcpyAtoD
* @{
* @ingroup MemoryTest
* `hipError_t hipMemcpyAtoD(hipDeviceptr_t dstDevice, hipArray_t srcArray,
* size_t srcOffset, size_t ByteCount)` -
* Copies from one 1D array to device memory.
*/
/**
* Test Description
* ------------------------
* - This testcase initially copies data from host to 1D array and then performs
* hipMemcpyAtoD api call and copies this device memory to host variable and
* verifies with initial host values.
* Test source
* ------------------------
* - unit/memory/hipMemcpyAtoD.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 6.2
*/
HIP_TEST_CASE(Unit_hipMemcpyAtoD_Basic) {
#if HT_NVIDIA
HIP_SKIP_TEST(HipTest::SkipReason::kApiUnsupportedOnNvidia);
#else
HIP_CHECK(hipSetDevice(0));
CHECK_IMAGE_SUPPORT
int row, col;
row = 1;
col = GENERATE(3, 4, 100);
int* A_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
int* B_h = reinterpret_cast<int*>(malloc(sizeof(int) * row * col));
for (int i = 0; i < (row * col); i++) {
A_h[i] = i;
}
hipArray_t A_a;
int* A_d;
hipChannelFormatDesc desc = hipCreateChannelDesc<int>();
HIP_CHECK(hipMallocArray(&A_a, &desc, col, row, hipArrayDefault));
HIP_CHECK(hipMalloc(&A_d, sizeof(int) * row * col));
hipError_t memcpy_err = hipSuccess;
BEGIN_CAPTURE_SYNC(memcpy_err, false);
HIP_CHECK_ERROR(hipMemcpy2DToArray(A_a, 0, 0, A_h, col * sizeof(int), col * sizeof(int), row,
hipMemcpyHostToDevice),
memcpy_err);
END_CAPTURE_SYNC(memcpy_err);
if (memcpy_err == hipSuccess) {
HIP_CHECK(hipMemcpyAtoD(A_d, A_a, 0, sizeof(int) * col * row));
HIP_CHECK(hipMemcpyDtoH(B_h, A_d, sizeof(int) * row * col));
for (int i = 0; i < (row * col); i++) {
REQUIRE(A_h[i] == B_h[i]);
}
}
HIP_CHECK(hipFreeArray(A_a));
HIP_CHECK(hipFree(A_d));
free(A_h);
free(B_h);
#endif
}
/**
* End doxygen group MemoryTest.
* @}
*/